Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: chrome/browser/autocomplete/autocomplete_edit_view_win.cc

Issue 60084: A quick fix for Issue 9596.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autocomplete/autocomplete_edit_view_win.cc
===================================================================
--- chrome/browser/autocomplete/autocomplete_edit_view_win.cc (revision 13063)
+++ chrome/browser/autocomplete/autocomplete_edit_view_win.cc (working copy)
@@ -648,14 +648,14 @@
size_t caret_pos) {
HIMC imm_context = ImmGetContext(m_hWnd);
if (imm_context) {
- // In Windows Vista, SetWindowText() automatically completes any ongoing
+ // In Windows Vista, SetWindowText() automatically cancels any ongoing
// IME composition, and updates the text of the underlying edit control.
// In Windows XP, however, SetWindowText() gets applied to the IME
// composition string if it exists, and doesn't update the underlying edit
// control. To avoid this, we force the IME to complete any outstanding
// compositions here. This is harmless in Vista and in cases where the IME
// isn't composing.
- ImmNotifyIME(imm_context, NI_COMPOSITIONSTR, CPS_COMPLETE, 0);
+ ImmNotifyIME(imm_context, NI_COMPOSITIONSTR, CPS_CANCEL, 0);
ImmReleaseContext(m_hWnd, imm_context);
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -648,14 +648,14 @@
// In Windows XP, however, SetWindowText() gets applied to the IME
// composition string if it exists, and doesn't update the underlying edit
- // control. To avoid this, we force the IME to complete any outstanding
+ // control. To avoid this, we force the IME to cancel any outstanding
// compositions here. This is harmless in Vista and in cases where the IME
// isn't composing.

Powered by Google App Engine
This is Rietveld 408576698